GNUPG-1-9-BRANCH gnupg (10 files)

cvs user wk cvs at cvs.gnupg.org
Tue Feb 22 18:57:13 CET 2005


    Date: Tuesday, February 22, 2005 @ 19:08:28
  Author: wk
    Path: /cvs/gnupg/gnupg
     Tag: GNUPG-1-9-BRANCH

   Added: doc/README.W32
Modified: TODO agent/ChangeLog agent/call-scd.c agent/command-ssh.c
          agent/learncard.c doc/ChangeLog doc/gpgsm.texi jnlib/ChangeLog
          jnlib/argparse.c

(stream_read_string): Removed call to abort on
memory error because the CVS version of libgcrypt makes sure
that ERRNO gets always set on error even with a faulty user
supplied function.


---------------------+
 TODO                |    2 ++
 agent/ChangeLog     |    7 +++++++
 agent/call-scd.c    |    2 +-
 agent/command-ssh.c |   13 +++++--------
 agent/learncard.c   |   28 ++++++++++++++++++++--------
 doc/ChangeLog       |    4 ++++
 doc/README.W32      |   42 ++++++++++++++++++++++++++++++++++++++++++
 doc/gpgsm.texi      |    6 ++++++
 jnlib/ChangeLog     |    3 ++-
 jnlib/argparse.c    |    2 +-
 10 files changed, 90 insertions(+), 19 deletions(-)


Index: gnupg/TODO
diff -u gnupg/TODO:1.165.2.36 gnupg/TODO:1.165.2.37
--- gnupg/TODO:1.165.2.36	Thu Jan 13 19:00:46 2005
+++ gnupg/TODO	Tue Feb 22 19:08:28 2005
@@ -54,6 +54,8 @@
 ** A SIGHUP should also restart the scdaemon
    But do this only after all connections terminated.  As of now we
    only send a RESET.
+** Watch the child process if not invoked as a daemon
+   and terminate after the child has terminated
 
 * agent/command.c
 ** Make sure that secure memory is used where appropriate
Index: gnupg/agent/ChangeLog
diff -u gnupg/agent/ChangeLog:1.59.2.66 gnupg/agent/ChangeLog:1.59.2.67
--- gnupg/agent/ChangeLog:1.59.2.66	Sat Feb 19 18:17:30 2005
+++ gnupg/agent/ChangeLog	Tue Feb 22 19:08:28 2005
@@ -1,3 +1,10 @@
+2005-02-22  Werner Koch  <wk at g10code.com>
+
+	* command-ssh.c (stream_read_string): Removed call to abort on
+	memory error because the CVS version of libgcrypt makes sure
+	that ERRNO gets always set on error even with a faulty user
+	supplied function.
+
 2005-02-19  Moritz Schulte  <moritz at g10code.com>
 
 	* command-ssh.c (ssh_receive_mpint_list): Slightly rewritten, do
Index: gnupg/agent/call-scd.c
diff -u gnupg/agent/call-scd.c:1.13.2.8 gnupg/agent/call-scd.c:1.13.2.9
--- gnupg/agent/call-scd.c:1.13.2.8	Mon Dec 20 09:32:56 2004
+++ gnupg/agent/call-scd.c	Tue Feb 22 19:08:28 2005
@@ -296,7 +296,7 @@
   return 0;
 }
 
-/* Perform the learn command and return a list of all private keys
+/* Perform the LEARN command and return a list of all private keys
    stored on the card. */
 int
 agent_card_learn (ctrl_t ctrl,
Index: gnupg/agent/command-ssh.c
diff -u gnupg/agent/command-ssh.c:1.1.4.9 gnupg/agent/command-ssh.c:1.1.4.10
--- gnupg/agent/command-ssh.c:1.1.4.9	Sat Feb 19 18:17:30 2005
+++ gnupg/agent/command-ssh.c	Tue Feb 22 19:08:28 2005
@@ -215,15 +215,12 @@
 
 
 
-
-
-
 /*
    General utility functions. 
  */
 
 /* A secure realloc, i.e. it makes sure to allocate secure memory if A
-   is NULL.  This is required becuase the standard gcry_realloc does
+   is NULL.  This is required because the standard gcry_realloc does
    not know whether to allocate secure or normal if NULL is passed as
    existing buffer.  */
 static void *
@@ -419,9 +416,7 @@
     buffer = xtrymalloc (length + 1);
   if (! buffer)
     {
-      /* FIXME: xtrymalloc_secure does not set errno, does it?  */
       err = gpg_error_from_errno (errno);
-      abort ();
       goto out;
     }
 
@@ -1530,6 +1525,8 @@
   free (key_directory);
   xfree (key_path);
   xfree (buffer);
+  /* FIXME: Ist is for sure is a Bad Thing to use the const qualifier
+     and later cast it away.  You can't do that!!! */
   xfree ((void *) key_type);		/* FIXME? */
 
   return ret_err;
@@ -2159,7 +2156,7 @@
   gpg_error_t err;
 
   /* FIXME */
-  log_error (_("lock command is not implemented\n"));
+  log_error ("ssh-agent's lock command is not implemented\n");
   err = 0;
 
   return err;
@@ -2170,7 +2167,7 @@
 {
   gpg_error_t err;
 
-  log_error (_("unlock command is not implemented\n"));
+  log_error ("ssh-agent's unlock command is not implemented\n");
   err = 0;
 
   return err;
Index: gnupg/doc/ChangeLog
diff -u gnupg/doc/ChangeLog:1.39.2.24 gnupg/doc/ChangeLog:1.39.2.25
--- gnupg/doc/ChangeLog:1.39.2.24	Thu Jan 27 00:15:42 2005
+++ gnupg/doc/ChangeLog	Tue Feb 22 19:08:28 2005
@@ -1,3 +1,7 @@
+2005-02-14  Werner Koch  <wk at g10code.com>
+
+	* gpgsm.texi (Certificate Management): Document --import.
+
 2005-01-27  Moritz Schulte  <moritz at g10code.com>
 
 	* gpg-agent.texi: Document ssh-agent emulation layer.
Index: gnupg/doc/README.W32
diff -u /dev/null gnupg/doc/README.W32:1.8.2.1
--- /dev/null	Tue Feb 22 19:08:28 2005
+++ gnupg/doc/README.W32	Tue Feb 22 19:08:28 2005
@@ -0,0 +1,42 @@
+                         README.W32 
+                        ============
+                         2004-12-22
+
+  This is a precompiled version of gnupg 1.9.14 for MS Windows.
+  Please see the manual (gnupg.pdf) for the current limitations.  Be
+  aware that this is the first released version and thus bugs are
+  pretty likely.
+
+  Please copy all files to the directory c:\gnupg and follow the
+  manual instructions.
+  
+  This software has been build using Debian's mingw package, version
+  3.3.1.20030804.1-1.  Libraries are all compiled statically, versions
+  of the used libraries are:
+  
+   gpg-error-config: 1.1-cvs
+   libgcrypt-config: 1.2.1-cvs
+   ksba-config: 0.9.11-cvs
+   libassuan-config: 0.6.9-cvs
+  
+  as these are all CVS versions you need to get the from the CVS.  See
+  www.gnupg.org for details.  Use 2004-12-22 18:00 UTC as revision
+  date.  The source code of GnuPG itsself is available at
+  ftp://ftp.gnupg.org/gcrypt/alpha/gnupg/gnupg-1.9.14.tar.bz2
+  ftp://ftp.gnupg.org/gcrypt/alpha/gnupg/gnupg-1.9.14.tar.bz2.sig
+  
+  Building has been done by running the command
+  
+   ./autogen.sh --build-w32
+  
+  for all these libraries and then for gnupg.  The PDF file has been
+  produced by first converting the logo file to pdf and the running
+  "make gnupg.pdf" in the doc directory.  All executables have been
+  stripped.
+  
+  In case of questions please contact us at info at g10code.com or better
+  write to the mailing list gnupg-devel at gnupg.org.
+  
+  Thanks,
+  
+    The g10 Code team  
Index: gnupg/doc/gpgsm.texi
diff -u gnupg/doc/gpgsm.texi:1.1.2.20 gnupg/doc/gpgsm.texi:1.1.2.21
--- gnupg/doc/gpgsm.texi:1.1.2.20	Tue Dec 21 20:05:15 2004
+++ gnupg/doc/gpgsm.texi	Tue Feb 22 19:08:28 2005
@@ -190,6 +190,12 @@
 PKCS#12 format is higly insecure and this command is only provided if
 there is no other way to exchange the private key.
 
+ at item --import [@var{files}]
+ at opindex import
+Import the certificates from the PEM or binary encoded files as well as
+from signed-only messages.  This command may also be used to import a
+secret key from a PKCS#12 file.
+
 @item --learn-card
 @opindex learn-card
 Read information about the private keys from the smartcard and import
Index: gnupg/jnlib/ChangeLog
diff -u gnupg/jnlib/ChangeLog:1.3.2.32 gnupg/jnlib/ChangeLog:1.3.2.33
--- gnupg/jnlib/ChangeLog:1.3.2.32	Thu Feb  3 14:20:57 2005
+++ gnupg/jnlib/ChangeLog	Tue Feb 22 19:08:28 2005
@@ -316,7 +316,8 @@
      * You may find it source-copied in other packages.        *
      ***********************************************************	
 	
- Copyright 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+ Copyright 2000, 2001, 2002, 2003, 2004,
+	   2005 Free Software Foundation, Inc.
 
  This file is free software; as a special exception the author gives
  unlimited permission to copy and/or distribute it, with or without
Index: gnupg/jnlib/argparse.c
diff -u gnupg/jnlib/argparse.c:1.3.2.3 gnupg/jnlib/argparse.c:1.3.2.4
--- gnupg/jnlib/argparse.c:1.3.2.3	Fri Jan 16 18:40:50 2004
+++ gnupg/jnlib/argparse.c	Tue Feb 22 19:08:28 2005
@@ -904,7 +904,7 @@
     switch( level ) {
       case 11: p = "foo"; break;
       case 13: p = "0.0"; break;
-      case 14: p = "Copyright (C) 2004 Free Software Foundation, Inc."; break;
+      case 14: p = "Copyright (C) 2005 Free Software Foundation, Inc."; break;
       case 15: p =
 "This program comes with ABSOLUTELY NO WARRANTY.\n"
 "This is free software, and you are welcome to redistribute it\n"




More information about the Gnupg-commits mailing list
Index: gnupg/agent/learncard.c
diff -u gnupg/agent/learncard.c:1.6.2.2 gnupg/agent/learncard.c:1.6.2.3
--- gnupg/agent/learncard.c:1.6.2.2	Thu Jan 29 21:17:27 2004
+++ gnupg/agent/learncard.c	Tue Feb 22 19:08:28 2005
@@ -31,11 +31,16 @@
 #include "agent.h"
 #include <assuan.h>
 
+/* Structures used by the callback mechanism to convey information
+   pertaining to key pairs.  */
 struct keypair_info_s {
   struct keypair_info_s *next;
   int no_cert;
-  char *id;  /* points into grip */
-  char hexgrip[1];
+  char *id;          /* points into grip */
+  char hexgrip[1];   /* The keygrip (i.e. a hash over the public key
+                        parameters) formatted as a hex string.
+                        Allocated somewhat large to also act as
+                        memeory for the above ID field. */
 };
 typedef struct keypair_info_s *KEYPAIR_INFO;
 
@@ -45,6 +50,9 @@
 };
 
 
+
+/* Structures used by the callback mechanism to convey information
+   pertaining to certificates.  */
 struct certinfo_s {
   struct certinfo_s *next;
   int type;  
@@ -59,6 +67,8 @@
 };
 
 
+/* Structures used by the callback mechanism to convey assuan status
+   lines.  */
 struct sinfo_s {
   struct sinfo_s *next;
   char *data;       /* Points into keyword. */
@@ -72,7 +82,7 @@
 };
 
 
-
+/* Destructor for key information objects. */
 static void
 release_keypair_info (KEYPAIR_INFO info)
 {
@@ -84,6 +94,7 @@
     }
 }
 
+/* Destructor for certificate information objects. */
 static void
 release_certinfo (CERTINFO info)
 {
@@ -95,6 +106,7 @@
     }
 }
 
+/* Destructor for status information objects. */
 static void
 release_sinfo (SINFO info)
 {
@@ -285,7 +297,7 @@
 }
 
 /* Perform the learn operation.  If ASSUAN_CONTEXT is not NULL all new
-   certificates are send via Assuan */
+   certificates are send back via Assuan.  */
 int
 agent_handle_learn (ctrl_t ctrl, void *assuan_context)
 {
@@ -317,7 +329,7 @@
   if (rc)
     goto leave;
 
-  /* now gather all the available info */
+  /* Now gather all the available info. */
   rc = agent_card_learn (ctrl, kpinfo_cb, &parm, certinfo_cb, &cparm,
                          sinfo_cb, &sparm);
   if (!rc && (parm.error || cparm.error || sparm.error))
@@ -371,15 +383,15 @@
         log_info ("          id: %s    (grip=%s)\n", item->id, item->hexgrip);
 
       if (item->no_cert)
-        continue; /* no public key yet available */
+        continue; /* No public key yet available. */
 
       for (p=item->hexgrip, i=0; i < 20; p += 2, i++)
         grip[i] = xtoi_2 (p);
       
       if (!agent_key_available (grip))
-        continue;
+        continue; /* The key is already available. */
       
       /* unknown - store it */
       rc = agent_card_readkey (ctrl, item->id, &pubkey);
       if (rc)
         {
@@ -371,15 +383,15 @@
       
-      /* unknown - store it */
+      /* Unknown key - store it. */
       rc = agent_card_readkey (ctrl, item->id, &pubkey);
       if (rc)